Plugins/WizardPlugins/QRegularExpressionWizard/QRegularExpressionWizardDialog.py

changeset 3670
f0cb7579c0b4
parent 3656
441956d8fce5
child 4021
195a471c327b
--- a/Plugins/WizardPlugins/QRegularExpressionWizard/QRegularExpressionWizardDialog.py	Sat Jul 05 11:41:14 2014 +0200
+++ b/Plugins/WizardPlugins/QRegularExpressionWizard/QRegularExpressionWizardDialog.py	Sat Jul 05 12:13:23 2014 +0200
@@ -41,7 +41,7 @@
         Constructor
         
         @param parent parent widget (QWidget)
-        @param fromEric flag indicating a call from within eric5
+        @param fromEric flag indicating a call from within eric6
         """
         super(QRegularExpressionWizardWidget, self).__init__(parent)
         self.setupUi(self)
@@ -462,7 +462,7 @@
         """
         Private slot to copy the QRegularExpression string into the clipboard.
         
         This slot is only available, if not called from within eric5.
         """
         escaped = self.regexpTextEdit.toPlainText()
         if escaped:
@@ -781,7 +781,7 @@
         Constructor
         
         @param parent parent widget (QWidget)
-        @param fromEric flag indicating a call from within eric5
+        @param fromEric flag indicating a call from within eric6
         """
         super(QRegularExpressionWizardDialog, self).__init__(parent)
         self.setModal(fromEric)
@@ -462,7 +462,7 @@
         Private slot to copy the QRegularExpression string into the clipboard.
         
-        This slot is only available, if not called from within eric5.
+        This slot is only available, if not called from within eric6.
         """
         escaped = self.regexpTextEdit.toPlainText()

eric ide

mercurial